==> ejc-wzxt-api-3.0.0-20200925.074509-9-sources.jar: com/ejianc/business/wzxt/vo/CheckVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 验收实体
 * 
 * @author generator
 * 
 */
public class CheckVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long orderId; // 订单主键
    private java.lang.Long deliveryId; // 发货主键
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.Long contractId; // 合同主键
    private java.lang.String contractName; // 合同名称
    private java.lang.Long supplierId; // 设备供应商
    private java.lang.String supplierName; // 供应商名称
    private java.lang.Long supplierTenantId; // 供应商租户ID
    private java.lang.String materialName; // 物资名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date checkDate; // 验收日期
    private java.lang.Long employeeId; // 验收人
    private java.lang.String employeeName; // 验收人名称
    private java.lang.String checkAddress; // 验收地点
    private java.lang.String checkType; // 业务类型
    private java.lang.Integer checkState; // 验收状态（1-保存态，0-暂存态）
    private java.lang.Integer isRequirement; // 是否满足质量要求0-是，1-否
    private java.lang.Integer isStandard; // 是否满足合同要求0-是，1-否
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String licensePlate; // 车牌号
    private java.lang.Integer useState; // 引用状态（0-未引用，1-已引用）

    // 验收明细子表
    private List<CheckDetailVO> checkDetail = new ArrayList<>();

    public List<CheckDetailVO> getCheckDetail() {
        return checkDetail;
    }

    public void setCheckDetail(List<CheckDetailVO> checkDetail) {
        this.checkDetail = checkDetail;
    }

    /**
     * 订单主键
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 发货主键
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    @ReferSerialTransfer(referCode="market-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    @ReferSerialTransfer(referCode="idm-org")
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    @ReferDeserialTransfer
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 合同主键
     */
    @ReferSerialTransfer(referCode="equipment-purchase-contract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备供应商
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    @ReferDeserialTransfer
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 供应商租户ID
     */
    public java.lang.Long getSupplierTenantId() {
        return supplierTenantId;
    }

    /**
     * 供应商租户ID
     */
    public void setSupplierTenantId(java.lang.Long supplierTenantId) {
        this.supplierTenantId = supplierTenantId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 验收日期
     */
    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 验收日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 验收人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 验收人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 验收人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 验收人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 验收地点
     */
    public java.lang.String getCheckAddress() {
        return checkAddress;
    }

    /**
     * 验收地点
     */
    public void setCheckAddress(java.lang.String checkAddress) {
        this.checkAddress = checkAddress;
    }
    /**
     * 业务类型
     */
    public java.lang.String getCheckType() {
        return checkType;
    }

    /**
     * 业务类型
     */
    public void setCheckType(java.lang.String checkType) {
        this.checkType = checkType;
    }
    /**
     * 验收状态（1-保存态，0-暂存态）
     */
    public java.lang.Integer getCheckState() {
        return checkState;
    }

    /**
     * 验收状态（1-保存态，0-暂存态）
     */
    public void setCheckState(java.lang.Integer checkState) {
        this.checkState = checkState;
    }
    /**
     * 是否满足质量要求0-是，1-否
     */
    public java.lang.Integer getIsRequirement() {
        return isRequirement;
    }

    /**
     * 是否满足质量要求0-是，1-否
     */
    public void setIsRequirement(java.lang.Integer isRequirement) {
        this.isRequirement = isRequirement;
    }
    /**
     * 是否满足合同要求0-是，1-否
     */
    public java.lang.Integer getIsStandard() {
        return isStandard;
    }

    /**
     * 是否满足合同要求0-是，1-否
     */
    public void setIsStandard(java.lang.Integer isStandard) {
        this.isStandard = isStandard;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 车牌号
     */
    public java.lang.String getLicensePlate() {
        return licensePlate;
    }

    /**
     * 车牌号
     */
    public void setLicensePlate(java.lang.String licensePlate) {
        this.licensePlate = licensePlate;
    }
    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public java.lang.Integer getUseState() {
        return useState;
    }

    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public void setUseState(java.lang.Integer useState) {
        this.useState = useState;
    }

}

==> ejc-wzxt-api-3.0.0-20200928.073655-11-sources.jar: com/ejianc/business/wzxt/vo/CheckVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 验收实体
 * 
 * @author generator
 * 
 */
public class CheckVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long orderId; // 订单主键
    private java.lang.Long deliveryId; // 发货主键
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.Long contractId; // 合同主键
    private java.lang.String contractName; // 合同名称
    private java.lang.Long supplierId; // 设备供应商
    private java.lang.String supplierName; // 供应商名称
    private java.lang.Long supplierTenantId; // 供应商租户ID
    private java.lang.String materialName; // 物资名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date checkDate; // 验收日期
    private java.lang.Long employeeId; // 验收人
    private java.lang.String employeeName; // 验收人名称
    private java.lang.String checkAddress; // 验收地点
    private java.lang.String checkType; // 业务类型
    private java.lang.Integer checkState; // 验收状态（1-保存态，0-暂存态，3-已验收）
    private java.lang.String isRequirement; // 是否满足质量要求0-是，1-否
    private java.lang.String isStandard; // 是否满足合同要求0-是，1-否
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String licensePlate; // 车牌号
    private java.lang.Integer useState; // 引用状态（0-未引用，1-已引用）
    private java.lang.String billStateName; // 单据状态名称
    private java.lang.String checkTypeName; // 业务类型名称
    private java.lang.String useStateName; // 引用状态名称

    public String getUseStateName() {
        return useStateName;
    }

    public void setUseStateName(String useStateName) {
        this.useStateName = useStateName;
    }

    public java.lang.String getCheckTypeName() {
        return checkTypeName;
    }

    public void setCheckTypeName(java.lang.String checkTypeName) {
        this.checkTypeName = checkTypeName;
    }

    public java.lang.String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(java.lang.String billStateName) {
        this.billStateName = billStateName;
    }

    // 验收明细子表
    private List<CheckDetailVO> detailList = new ArrayList<>();

    public List<CheckDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CheckDetailVO> detailList) {
        this.detailList = detailList;
    }

    /**
     * 订单主键
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 发货主键
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    @ReferSerialTransfer(referCode="market-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    @ReferSerialTransfer(referCode="idm-org")
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    @ReferDeserialTransfer
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 合同主键
     */
    @ReferSerialTransfer(referCode="equipment-purchase-contract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备供应商
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    @ReferDeserialTransfer
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 供应商租户ID
     */
    public java.lang.Long getSupplierTenantId() {
        return supplierTenantId;
    }

    /**
     * 供应商租户ID
     */
    public void setSupplierTenantId(java.lang.Long supplierTenantId) {
        this.supplierTenantId = supplierTenantId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 验收日期
     */
    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 验收日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 验收人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 验收人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 验收人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 验收人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 验收地点
     */
    public java.lang.String getCheckAddress() {
        return checkAddress;
    }

    /**
     * 验收地点
     */
    public void setCheckAddress(java.lang.String checkAddress) {
        this.checkAddress = checkAddress;
    }
    /**
     * 业务类型
     */
    public java.lang.String getCheckType() {
        return checkType;
    }

    /**
     * 业务类型
     */
    public void setCheckType(java.lang.String checkType) {
        this.checkType = checkType;
    }
    /**
     * 验收状态（1-保存态，0-暂存态）
     */
    public java.lang.Integer getCheckState() {
        return checkState;
    }

    /**
     * 验收状态（1-保存态，0-暂存态）
     */
    public void setCheckState(java.lang.Integer checkState) {
        this.checkState = checkState;
    }
    /**
     * 是否满足质量要求0-是，1-否
     */
    public java.lang.String getIsRequirement() {
        return isRequirement;
    }

    /**
     * 是否满足质量要求0-是，1-否
     */
    public void setIsRequirement(java.lang.String isRequirement) {
        this.isRequirement = isRequirement;
    }
    /**
     * 是否满足合同要求0-是，1-否
     */
    public java.lang.String getIsStandard() {
        return isStandard;
    }

    /**
     * 是否满足合同要求0-是，1-否
     */
    public void setIsStandard(java.lang.String isStandard) {
        this.isStandard = isStandard;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 车牌号
     */
    public java.lang.String getLicensePlate() {
        return licensePlate;
    }

    /**
     * 车牌号
     */
    public void setLicensePlate(java.lang.String licensePlate) {
        this.licensePlate = licensePlate;
    }
    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public java.lang.Integer getUseState() {
        return useState;
    }

    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public void setUseState(java.lang.Integer useState) {
        this.useState = useState;
    }

}
